Raw tables downloaded from Japan Meteorological Agency web pages, before cleaning into data(climate_jp_full). Kept for reproducibility of data-raw/climate_jp_full.R. Each element is a table of a station of data(station_jp_full), and the order of the elements is the same as the rows of the data. Column names are not set, and the first rows are headers of the web page. https://www.data.jma.go.jp/obd/stats/etrn/index.php